==> tasker-akka-10.3.0-802.1541-sources.jar: com/xebialabs/deployit/engine/tasker/IEngine.java <==
package com.xebialabs.deployit.engine.tasker;

import java.util.List;

import com.xebialabs.deployit.engine.api.execution.FetchMode;
import com.xebialabs.deployit.engine.api.execution.TaskWithBlock;
import org.joda.time.DateTime;

import org.springframework.security.core.Authentication;

public interface IEngine {
    String register(TaskSpecification spec);

    void prepareRollback(String taskid, TaskSpecification rollbackSpec);

    Task retrieve(String taskid);

    void execute(String taskid);

    void schedule(String taskid, DateTime scheduleAt);

    void abort(String taskid);

    void stop(String taskid);

    default void cancel(String taskid) {
        cancel(taskid, false);
    }

    void cancel(String taskid, boolean force);

    // can be removed once the com.xebialabs.deployit.engine.api.TaskService is removed
    @Deprecated
    void skipSteps(String taskid, List<Integer> stepNrs);

    // can be removed once the com.xebialabs.deployit.engine.api.TaskService is removed
    @Deprecated
    void unskipSteps(String taskid, List<Integer> stepNrs);

    void skipStepPaths(String taskid, List<BlockPath> stepNrs);

    void unskipStepPaths(String taskid, List<BlockPath> stepNrs);

    void addPauseStep(String taskid, BlockPath position);

    // can be removed once the com.xebialabs.deployit.engine.api.TaskService is removed
    @Deprecated
    void addPauseStep(String taskid, Integer position);

    List<TaskWithBlock> getAllIncompleteTasks(FetchMode fetchMode);

    void archive(String taskid);

    Task assign(String taskid, Authentication owner);

    List<String> reregisterGhostTasks();
}

==> tasker-akka-23.1.8-sources.jar: com/xebialabs/deployit/engine/tasker/IEngine.java <==
package com.xebialabs.deployit.engine.tasker;

import java.util.List;

import com.xebialabs.deployit.engine.api.execution.FetchMode;
import com.xebialabs.deployit.engine.api.execution.TaskWithBlock;
import org.joda.time.DateTime;

import org.springframework.security.core.Authentication;

public interface IEngine {
    String register(TaskSpecification spec);

    void prepareRollback(String taskid, TaskSpecification rollbackSpec);

    Task retrieveTask(String taskid);

    TaskWithBlock retrieveTaskSummary(String taskid);

    void execute(String taskid);

    void schedule(String taskid, DateTime scheduleAt);

    void abort(String taskid);

    void stop(String taskid);

    default void cancel(String taskid) {
        cancel(taskid, false);
    }

    void cancel(String taskid, boolean force);

    // can be removed once the com.xebialabs.deployit.engine.api.TaskService is removed
    @Deprecated
    void skipSteps(String taskid, List<Integer> stepNrs);

    // can be removed once the com.xebialabs.deployit.engine.api.TaskService is removed
    @Deprecated
    void unskipSteps(String taskid, List<Integer> stepNrs);

    void skipStepPaths(String taskid, List<BlockPath> stepNrs);

    void unskipStepPaths(String taskid, List<BlockPath> stepNrs);

    void addPauseStep(String taskid, BlockPath position);

    // can be removed once the com.xebialabs.deployit.engine.api.TaskService is removed
    @Deprecated
    void addPauseStep(String taskid, Integer position);

    List<TaskWithBlock> getAllIncompleteTasks(FetchMode fetchMode);

    void archive(String taskid);

    TaskWithBlock assign(String taskid, Authentication owner);

    List<String> reregisterGhostTasks();
}
